# What's Changed

> 新版本预告: v4.0.0 即将发布。

1. 新增: 添加对 ModelScope、Compshare（优云智算）的模版支持。
2. 优化: 增加插件数据缓存，优化插件市场数据获取时的稳定性。

其他更新:

1. 现已支持在 1Panel 平台通过应用商城快捷部署 AstrBot。详见：[在 1Panel 部署 AstrBot](https://docs.astrbot.app/deploy/astrbot/1panel.html)
